@@ -2,15 +2,33 @@ context("sim_sample")
 test_that("Attributes are preserved", {
   setup <- sim_base(base_id(nDomains=3, nUnits = 4)) %>%
     sim_gen_x(mean=50, sd=20, name = "x") %>%
-    sim_gen_e(0, 1, name = "e") %>% 
+    sim_gen_e(0, 1, name = "e") %>%
     sim_comp_pop(function(dat) {attr(dat, "x") <- 2; dat})
-  
-  setup %>% sim_sample(sample_number(2)) %>% as.data.frame %>% attr("x") %>% expect_equal(2)
-  setup %>% sim_sample(sample_fraction(0.2)) %>% as.data.frame %>% attr("x") %>% expect_equal(2)
-  
-  setup %>% sim_sample(sample_number(2, groupVars = "idD")) %>% as.data.frame %>% attr("x") %>% expect_equal(2)
-  setup %>% sim_sample(sample_fraction(0.2, groupVars = "idD")) %>% as.data.frame %>% attr("x") %>% expect_equal(2)
-  
+
+  setup %>%
+    sim_sample(sample_number(2)) %>%
+    as.data.frame %>%
+    attr("x") %>%
+    expect_equal(2)
+
+  setup %>%
+    sim_sample(sample_fraction(0.2)) %>%
+    as.data.frame %>%
+    attr("x") %>%
+    expect_equal(2)
+
+  setup %>%
+    sim_sample(sample_number(2, groupVars = "idD")) %>%
+    as.data.frame %>%
+    attr("x") %>%
+    expect_equal(2)
+
+  setup %>%
+    sim_sample(sample_fraction(0.2, groupVars = "idD")) %>%
+    as.data.frame %>%
+    attr("x") %>%
+    expect_equal(2)
+
 })
 
 test_that("Basic sampling functionality", {
@@ -75,4 +93,4 @@ test_that("sampling of clusters", {
   expect_equal(attr(dat2, "x"), 1)
   expect_equal(nrow(dat2), 20)
   expect_equal(length(unique(dat2$idD)), 2)
-})
\ No newline at end of file
+})
